; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "QCF_PP"
command = ~D, DF, F, x+y
time = 20

[Command]
name = "QCF_PP"
command = ~D, DF, F, x+z
time = 20

[Command]
name = "QCF_PP"
command = ~D, DF, F, y+z
time = 20

[Command]
name = "QCB_PP"
command = ~D, DB, B, x+y
time = 20

[Command]
name = "QCB_PP"
command = ~D, DB, B, x+z
time = 20

[Command]
name = "QCB_PP"
command = ~D, DB, B, y+z
time = 20

[Command]
name = "QCF_KK"
command = ~D, DF, F, a+b
time = 20

[Command]
name = "QCF_KK"
command = ~D, DF, F, a+c
time = 20

[Command]
name = "QCF_KK"
command = ~D, DF, F, b+c
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "BF_x"
command = ~30$B, F, x

[Command]
name = "BF_y"
command = ~30$B, F, y

[Command]
name = "BF_z"
command = ~30$B, F, z

[Command]
name = "DU_x"
command = ~30$D, U, x

[Command]
name = "DU_y"
command = ~30$D, U, y

[Command]
name = "DU_z"
command = ~30$D, U, z

[Command]
name = "HCB_a"
command = ~F, $D, B, a

[Command]
name = "HCB_a"
command = ~F, $D, B, ~a

[Command]
name = "HCB_b"
command = ~F, $D, B, b

[Command]
name = "HCB_b"
command = ~F, $D, B, ~b

[Command]
name = "HCB_c"
command = ~F, $D, B, c

[Command]
name = "HCB_c"
command = ~F, $D, B, ~c

[Command]
name = "HCF_x"
command = ~B, $D, F, x

[Command]
name = "HCF_x"
command = ~B, $D, F, ~x

[Command]
name = "HCF_y"
command = ~B, $D, F, y

[Command]
name = "HCF_y"
command = ~B, $D, F, ~y

[Command]
name = "HCF_z"
command = ~B, $D, F, z

[Command]
name = "HCF_z"
command = ~B, $D, F, ~z

[Command]
name = "HCF_a"
command = ~B, $D, F, a

[Command]
name = "HCF_a"
command = ~B, $D, F, ~a

[Command]
name = "HCF_b"
command = ~B, $D, F, b

[Command]
name = "HCF_b"
command = ~B, $D, F, ~b

[Command]
name = "HCF_c"
command = ~B, $D, F, c

[Command]
name = "HCF_c"
command = ~B, $D, F, ~c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "DU"
command = D, U
time = 10

[Command]
name = "DUF"
command = D, UF
time = 10

[Command]
name = "DUB"
command = D, UB
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Multiple Button |---------------------------------------------------------
[Command]
name = "abc"
command = a+b+c
time = 1

[Command]
name = "xyz"
command = x+y+z
time = 1

[Command]
name = "xa"
command = x+a
time = 1
[Command]
name = "yb"
command = y+b
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

;-| AI |--------------------------------------------------------------
[Command]
name = "AI1"
command = U,D,B,F,U,D,B,F,b,b,a,a,s
time = 0

[Command]
name = "AI2"
command = U,D,U,D,U,D,U,D,U,D,U,D,a+b+c+x+y+z
time = 0

[Command]
name = "AI3"
command = U,F,B,D,B,F,U,x,x,x,y,y,y,z,z,z
time = 0

[Command]
name = "AI4"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0

[Command]
name = "AI5"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0

[Command]
name = "AI6"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0

[Command]
name = "AI7"
command = x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z,x+y+z
time = 0

[Command]
name = "AI8"
command = a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c,a+b+c
time = 0

[Command]
name = "AI9"
command = y,a,B,B,a,D,a,B,B,a
time = 0

[Command]
name = "AI10"
command = c,U,B,B,y,B,U,D,D,y
time = 0

[Command]
name = "AI11"
command = x,x
time = 0

[Command]
name = "AI12"
command = y,y
time = 0

[Command]
name = "AI13"
command = z,z
time = 0

[Command]
name = "AI14"
command = a,a
time = 0

[Command]
name = "AI15"
command = b,b
time = 0

[Command]
name = "AI16"
command = c,c
time = 0

[Command]
name = "AI17"
command = U,x
time = 0

[Command]
name = "AI18"
command = D,x
time = 0

[Command]
name = "AI19"
command = B,x
time = 0

[Command]
name = "AI20"
command = F,x
time = 0

[Command]
name = "KonamiCode"
command = U,U,D,D,B,F,B,F,b,a,s
time = 0

[Command]
name = "aXOR"
command = a
time = 1

[Command]
name = "bXOR"
command = b
time = 1

[Command]
name = "cXOR"
command = c
time = 1

[Command]
name = "xXOR"
command = x
time = 1

[Command]
name = "yXOR"
command = y
time = 1

[Command]
name = "zXOR"
command = z
time = 1

[Command]
name = "startXOR"
command = s
time = 1

[Command]
name = "holdfwdXOR"
command = /$F
time = 1

[Command]
name = "holdbackXOR"
command = /$B
time = 1

[Command]
name = "holdupXOR"
command = /$U
time = 1

[Command]
name = "holddownXOR"
command = /$D
time = 1

[Command]
name = "holdxXOR"
command = /x
time = 1

[Command]
name = "holdyXOR"
command = /y
time = 1

[Command]
name = "holdzXOR"
command = /z
time = 1

[Command]
name = "holdaXOR"
command = /a
time = 1

[Command]
name = "holdbXOR"
command = /b
time = 1

[Command]
name = "holdcXOR"
command = /c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
; AI
;===========================================================================
;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
triggerall = var(59) = 0
triggerall = var(57) != 1 ; Difficulty level not set to No AI
trigger1 = IsHomeTeam
trigger1 = TeamSide = 2
trigger2 = command = "KonamiCode"
trigger3 = command = "AI1"
trigger4 = command = "AI2"
trigger5 = command = "AI3"
trigger6 = command = "AI4"
trigger7 = command = "AI5"
trigger8 = command = "AI6"
trigger9 = command = "AI7"
trigger10 = command = "AI8"
trigger11 = command = "AI9"
trigger12 = command = "AI10"
trigger13 = command = "AI11"
trigger14 = command = "AI12"
trigger15 = command = "AI13"
trigger16 = command = "AI14"
trigger17 = command = "AI15"
trigger18 = command = "AI16"
trigger19 = command = "AI17"
trigger20 = command = "AI18"
trigger21 = command = "AI19"
trigger22 = command = "AI20"
trigger23 = command = "a" ^^ command = "aXOR"
trigger24 = command = "b" ^^ command = "bXOR"
trigger25 = command = "c" ^^ command = "cXOR"
trigger26 = command = "x" ^^ command = "xXOR"
trigger27 = command = "y" ^^ command = "yXOR"
trigger28 = command = "z" ^^ command = "zXOR"
trigger29 = command = "start" ^^ command = "startXOR"
trigger30 = command = "holdfwd" ^^ command = "holdfwdXOR"
trigger31 = command = "holdback" ^^ command = "holdbackXOR"
trigger32 = command = "holdup" ^^ command = "holdupXOR"
trigger33 = command = "holddown" ^^ command = "holddownXOR"
trigger34 = command = "holda" ^^ command = "holdaXOR"
trigger35 = command = "holdb" ^^ command = "holdbXOR"
trigger36 = command = "holdc" ^^ command = "holdcXOR"
trigger37 = command = "holdx" ^^ command = "holdxXOR"
trigger38 = command = "holdy" ^^ command = "holdyXOR"
trigger39 = command = "holdz" ^^ command = "holdzXOR"
v = 59
value = 1

;---------------------------------------------------------------------------
;Activate AI
[State -1, Activate AI]
type = VarSet
trigger1 = var(59) = 2
trigger1 = RoundState != 3
v = 59
value = 1

;---------------------------------------------------------------------------
;Deactivate AI
[State -1, Deactivate AI]
type = VarSet
triggerall = var(59) != 0
trigger1 = RoundState = 3
v = 59
value = 2

;---------------------------------------------------------------------------
;Liedown AI
[State -1, Liedown AI]
type = VarSet
triggerall = var(59) = 1
trigger1 = p2statetype = L
trigger2 = p2stateno = [5050,5079]
v = 59
value = 4

;---------------------------------------------------------------------------
;Liedown AI Off
[State -1, Liedown AI Off]
type = VarSet
triggerall = var(59) = 4
trigger1 = p2statetype != L
trigger1 = p2stateno != [5050,5079]
v = 59
value = 1

;---------------------------------------------------------------------------
;Check Miss AI Begin Attack
[State -1, Check Miss AI Begin Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) <= 0
trigger1 = movetype = A
v = 58
value = stateno

;---------------------------------------------------------------------------
;Check Miss AI Hit
[State -1, Check Miss AI Hit]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) != 0
trigger1 = movecontact
trigger2 = movetype = I
trigger2 = random < 10
trigger3 = stateno = [150,159]
v = 58
value = 0

;---------------------------------------------------------------------------
;Check Miss AI End Attack
[State -1, Check Miss AI End Attack]
type = VarSet
triggerall = var(59) != 0
triggerall = var(58) > 0
trigger1 = ctrl = 1
v = 58
value = var(58)*(-1)

;===========================================================================
; Super Armor
;===========================================================================
;---------------------------------------------------------------------------
[State -1, Trigger Super Armor]
type = ChangeState
value = 3300
trigger1 = Life < 250
trigger1 = var(5) = 0
trigger1 = ctrl
trigger1 = StateType != A

;===========================================================================
; AI Guard
;===========================================================================
;---------------------------------------------------------------------------
;AI Guard (Standing)
[State -1, AI Guard (Standing)]
type = ChangeState
value = 130
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (ctrl && statetype != A) || (stateno = 100) || (stateno = 105)
triggerall = p2statetype != C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Crouching)
[State -1, AI Guard (Crouching)]
type = ChangeState
value = 131
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (ctrl && statetype != A) || (stateno = 100) || (stateno = 105)
triggerall = p2statetype = C
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard (Air)
[State -1, AI Guard (Air)]
type = ChangeState
value = 132
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = statetype = A
triggerall = ctrl
trigger1 = inguarddist

;---------------------------------------------------------------------------
;AI Guard Push (Stand)
[State -1, Guard Push (Stand)]
type = ChangeState
value = 160
triggerall = stateno = 150
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = statetype = S
ignorehitpause = 1

;---------------------------------------------------------------------------
;AI Guard Push (Crouch)
[State -1, Guard Push (Crouch)]
type = ChangeState
value = 161
triggerall = stateno = 152
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = statetype = C
ignorehitpause = 1

;---------------------------------------------------------------------------
;AI Guard Push (Air)
[State -1, Guard Push (Air)]
type = ChangeState
value = 162
triggerall = stateno = 154
triggerall = var(59) != 0
triggerall = var(57) != 2 ; Difficulty level
triggerall = (var(57) = 4) || ((random < 250) && Time <= 1) ; Difficulty level
trigger1 = statetype = A
ignorehitpause = 1

;===========================================================================
; AI Throws
;===========================================================================
;---------------------------------------------------------------------------
;AI Throw A
[State -1, AI Throw A]
type = ChangeState
value = 800
triggerall = var(59) = 1
triggerall = statetype = S
triggerall = ctrl
triggerall = (abs(var(58)) != [800,899])|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = p2bodydist X = [0,5]
trigger1 = random < 750
trigger1 = p2statetype != A
trigger1 = p2movetype != H

;---------------------------------------------------------------------------
;AI Air Throw
[State -1, AI Air Throw]
type = ChangeState
value = 830
triggerall = var(59) = 1
triggerall = statetype = A
triggerall = ctrl
trigger1 = p2bodydist X = [0,5]
trigger1 = p2statetype = A
trigger1 = p2movetype != H

;---------------------------------------------------------------------------
;AI Throw B
[State -1, AI Throw B]
type = ChangeState
value = 840
triggerall = var(59) = 1
triggerall = statetype = S
triggerall = ctrl
triggerall = (abs(var(58)) != [800,899])|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = p2bodydist X = [0,5]
trigger1 = p2statetype != A
trigger1 = p2movetype != H

;===========================================================================
; AI Poke
;===========================================================================
;---------------------------------------------------------------------------
;AI Stand Medium Punch (Poke)
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
triggerall = (abs(var(58)) != 210)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = p2movetype = I
trigger1 = P2BodyDist X = [40,0]
trigger1 = P2Dist Y = [0,10]
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
; AI Ground Combo
;===========================================================================
;---------------------------------------------------------------------------
;AI Stand Medium Punch
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
triggerall = movecontact
trigger1 = stateno = 230
trigger2 = stateno = 430

;---------------------------------------------------------------------------
;AI Stand Medium Kick
[State -1, AI Stand Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 1
triggerall = movecontact
trigger1 = stateno = 200
trigger2 = stateno = 400

;===========================================================================
; AI Aerial Rave
;===========================================================================
;---------------------------------------------------------------------------
;AI Stand Medium Punch
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
triggerall = movecontact
trigger1 = stateno = 200
trigger2 = stateno = 230
trigger3 = stateno = 400
trigger4 = stateno = 430

;---------------------------------------------------------------------------
;AI Aerial Rave On
[State -1, AI Aerial Rave On]
type = VarSet
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = StateNo = 210
trigger1 = AnimElem = 15, >= 0
trigger1 = AnimElem = 16, < 0
trigger1 = MoveHit
v = 59
value = 3

;---------------------------------------------------------------------------
;AI Super Jump
[State -1, AI Super Jump]
type = ChangeState
value = 110
triggerall = var(59) = 3
trigger1 = stateno = 210
trigger1 = MoveHit >= 12

;---------------------------------------------------------------------------
;AI Super Jump Forwards
[State 110, AI Super Jump Forwards]
type = VelSet 
triggerall = var(59) = 3
trigger1 = StateNo = 111
x = 2.5

;---------------------------------------------------------------------------
;Aerial Rave Over
[State -1, Aerial Rave Over]
type = VarSet
triggerall = var(59) = 3
trigger1 = statetype != A
trigger2 = stateno = 600
v = 59
value = 1

;---------------------------------------------------------------------------
;AI Jump Light Punch
[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 3
trigger1 = P2BodyDist X = [0,50]
trigger1 = P2Dist Y = [-40,30]
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;AI Jump Light Kick
[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 1
trigger1 = movecontact
trigger1 = stateno = 600

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 1
trigger1 = movecontact
trigger1 = stateno = 630
trigger1 = random < 250

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 1
trigger1 = movecontact
trigger1 = stateno = 630
trigger1 = random < 667

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 1
trigger1 = movecontact
trigger1 = stateno = 630

;===========================================================================
; AI Super Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Saotome Cyclone
[State -1, AI Saotome Cyclone]
type = ChangeState
value = 3200
triggerall = var(59) = 1
triggerall = power >= 1000
triggerall = statetype != A
triggerall = p2bodydist X = [-40,40]
triggerall = ctrl
trigger1 = P2MoveType = I
trigger1 = enemy, ctrl = 0
trigger2 = p2dist Y > 100

;---------------------------------------------------------------------------
;AI Blodia Punch
[State -1, AI Blodia Punch]
type = ChangeState
value = 3000
triggerall = var(59) = 1
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,80]
trigger1 = p2dist Y = [-10,0]
trigger1 = BackEdgeBodyDist < 60

;---------------------------------------------------------------------------
;AI Blodia Vulcan
[State -1, AI Blodia Vulcan]
type = ChangeState
value = 3100
triggerall = var(59) = 1
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger1 = P2MoveType = I
trigger1 = enemy, ctrl = 0
trigger1 = P2BodyDist Y = [-200,0]
trigger2 = ctrl
trigger2 = P2MoveType = A
trigger2 = P2BodyDist X > 180
trigger2 = P2BodyDist Y = [-200,0]

;===========================================================================
; AI Special Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Saotome Typhoon
[State -1, AI Saotome Typhoon]
type = ChangeState
value = 1000
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = p2bodydist X = [0,40]
trigger1 = p2movetype = I
trigger1 = enemy, ctrl = 0

;---------------------------------------------------------------------------
;AI Saotome Typhoon
[State -1, AI Saotome Typhoon]
type = ChangeState
value = 1010
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = p2bodydist X = [0,50]
trigger1 = p2movetype = I
trigger1 = enemy, ctrl = 0

;---------------------------------------------------------------------------
;AI Saotome Typhoon
[State -1, AI Saotome Typhoon]
type = ChangeState
value = 1020
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = ctrl
trigger1 = p2bodydist X = [0,160]
trigger1 = p2movetype = I
trigger1 = enemy, ctrl = 0

;---------------------------------------------------------------------------
;AI Saotome Dynamite
[State -1, AI Saotome Dynamite]
type = ChangeState
value = 1100
triggerall = statetype != A
triggerall = (abs(var(58)) != 1100)|| (Random < 70)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
triggerall = NumTarget(800) = 0
trigger1 = var(59) = 1
trigger1 = p2bodydist X = [-80,80]
trigger1 = p2bodydist Y = [-140,5]
trigger1 = p2statetype = A
trigger1 = ctrl || (movecontact || time > 25) && (stateno = 400 || stateno = 410 || stateno = 430 || stateno = 450) || stateno = 252
trigger2 = var(59) = 4
trigger2 = p2statetype != L
trigger2 = p2bodydist X = [-80,80]
trigger2 = p2bodydist Y = [-140,5]
trigger2 = ctrl || (movecontact || time > 25) && (stateno = 400 || stateno = 410 || stateno = 430 || stateno = 450) || stateno = 252
trigger2 = stateno != 5120
trigger3 = var(59) != 0
trigger3 = movecontact
trigger3 = stateno = 450
trigger3 = random < 100
trigger3 = p2bodydist X = [-80,80]
trigger3 = p2bodydist Y = [-140,5]

;===========================================================================
; AI Normal Moves
;===========================================================================
;---------------------------------------------------------------------------
;AI Crouch Light Punch
[State -1, AI Crouch Light Punch]
type = ChangeState
value = 400
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 400)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,40]
trigger1 = p2bodydist Y = 0
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Crouch Light Kick
[State -1, AI Crouch Light Kick]
type = ChangeState
value = 430
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 430)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,45]
trigger1 = p2bodydist Y = 0
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Crouch Medium Punch
[State -1, AI Crouch Medium Punch]
type = ChangeState
value = 410
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 410)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,50]
trigger1 = p2bodydist Y = 0
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Crouch Medium Kick
[State -1, AI Crouch Medium Kick]
type = ChangeState
value = 440
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,55]
trigger1 = p2bodydist Y = [-60,0]
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Crouch Strong Punch
[State -1, AI Crouch Strong Punch]
type = ChangeState
value = 420
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 420)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,60]
trigger1 = p2bodydist Y = 0
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Crouch Strong Kick
[State -1, AI Crouch Strong Kick]
type = ChangeState
value = 450
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,120]
trigger1 = p2bodydist Y = 0
trigger1 = (p2statetype = C && Random < 333) || (p2statetype = S && Random < 667)

;---------------------------------------------------------------------------
;AI Stand Light Punch
[State -1, AI Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 200)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,40]
trigger1 = p2bodydist Y = [-50,0]

;---------------------------------------------------------------------------
;AI Stand Medium Punch
[State -1, AI Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 210)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,50]
trigger1 = p2bodydist Y = [-50,0]

;---------------------------------------------------------------------------
;AI Stand High Punch
[State -1, AI Stand High Punch]
type = ChangeState
value = 220
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,100]
trigger1 = p2bodydist Y = [-50,0]

;---------------------------------------------------------------------------
;AI Stand Light Kick
[State -1, AI Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = (abs(var(58)) != 230)|| (Random < 100)
triggerall = (var(58) != [200,499]) || (Random < 100)
triggerall = (var(58) != [1000,3999]) || (Random < 150)
trigger1 = ctrl
trigger1 = p2bodydist X = [0,55]
trigger1 = p2bodydist Y = [-50,0]

;---------------------------------------------------------------------------
;AI Stand Medium Kick
[State -1, AI Stand Medium Kick]
type = ChangeState
value = 240
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,100]
trigger1 = p2bodydist X + 2*p2bodydist Y = [-30,30]
trigger1 = p2statetype = A

;---------------------------------------------------------------------------
;AI Stand Strong Kick
[State -1, AI Stand Strong Kick]
type = ChangeState
value = 250
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,120]
trigger1 = p2bodydist Y = [0,0]

;---------------------------------------------------------------------------
;AI Jump Light Punch
[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*2 = [0,40]
trigger1 = p2bodydist Y+(vel Y)*2 = [-20,20]

;---------------------------------------------------------------------------
;AI Jump Medium Punch
[State -1, AI Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*4 = [0,40]
trigger1 = p2bodydist Y+(vel Y)*4 = [-30,15]

;---------------------------------------------------------------------------
;AI Jump Strong Punch
[State -1, AI Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*10 = [0,40]
trigger1 = p2bodydist Y+(vel Y)*10 = [-5,40]

;---------------------------------------------------------------------------
;AI Jump Light Kick
[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*2 = [0,45]
trigger1 = p2bodydist Y+(vel Y)*2 = [-30,50]

;---------------------------------------------------------------------------
;AI Jump Medium Kick
[State -1, AI Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*10 = [0,60]
trigger1 = p2bodydist Y+(vel Y)*10 = [-30,50]

;---------------------------------------------------------------------------
;AI Jump Down Strong Kick
[State -1, AI Jump Down Strong Kick]
type = ChangeState
value = 655
triggerall = var(59) = 1
trigger1 = Pos Y <= -60
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X = [0,180]
trigger1 = 2*p2bodydist X + p2bodydist Y = [-30,50]

;---------------------------------------------------------------------------
;AI Jump Strong Kick
[State -1, AI Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(59) = 1
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2bodydist X+(vel X)*6 = [0,80]
trigger1 = p2bodydist Y+(vel Y)*6 = [-40,30]

;===========================================================================
; AI Misc
;===========================================================================
;---------------------------------------------------------------------------
;AI Run Fwd
[State -1, AI Run Fwd]
type = ChangeState
value = 100
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = stateno != 100
trigger1 = stateno != 105
trigger1 = Random < 20

;---------------------------------------------------------------------------
;AI Run Back
[State -1, AI Run Back]
type = ChangeState
value = 105
triggerall = var(59) = 1
triggerall = statetype != A
trigger1 = ctrl
trigger1 = stateno != 100
trigger1 = stateno != 105
trigger1 = Random < 5

;---------------------------------------------------------------------------
;AI Super Jump
[State -1, AI Super Jump]
type = ChangeState
value = 110
triggerall = var(59) = 1
triggerall = statetype != A
triggerall = command = "holdfwd"
trigger1 = ctrl
trigger1 = p2bodydist x > 120
trigger1 = random < 200

;===========================================================================
; Non-AI Commands
;===========================================================================
;---------------------------------------------------------------------------
;Blodia Punch
[State -1, Blodia Punch]
type = ChangeState
value = 3000
triggerall = command = "QCF_PP"
triggerall = power >= 1000
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Blodia Vulcan
[State -1, Blodia Vulcan]
type = ChangeState
value = 3100
triggerall = command = "QCB_PP"
triggerall = power >= 1000
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Saotome Cyclone
[State -1, Saotome Cyclone]
type = ChangeState
value = 3200
triggerall = command = "QCF_KK"
triggerall = power >= 1000
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;===========================================================================
;---------------------------------------------------------------------------
;Saotome Typhoon
[State -1, Saotome Typhoon]
type = ChangeState
value = 1000
triggerall = command = "BF_x"
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Saotome Typhoon
[State -1, Saotome Typhoon]
type = ChangeState
value = 1010
triggerall = command = "BF_y"
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Saotome Typhoon
[State -1, Saotome Typhoon]
type = ChangeState
value = 1020
triggerall = command = "BF_z"
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Saotome Dynamite
[State -1, Saotome Dynamite]
type = ChangeState
value = 1100
triggerall = (command = "DU_x") || (command = "DU_y") ||(command = "DU_z")
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 40
trigger3 = stateno = 252
trigger4 = stateno = 400
trigger5 = stateno = 410
trigger6 = stateno = 420
trigger7 = stateno = 430
trigger8 = stateno = 450

;---------------------------------------------------------------------------
;Saotome Crush
[State -1, Saotome Crush]
type = ChangeState
value = 1200
triggerall = (command = "HCB_a") || (command = "HCB_b") || (command = "HCB_c")
triggerall = statetype != A
triggerall = var(59) = 0
trigger1 = ctrl
trigger2 = stateno = [200,499]

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
triggerall = var(59) = 0
triggerall = statetype = S
trigger1 = ctrl
trigger1 = stateno != [100, 109]

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = command = "BB"
triggerall = var(59) = 0
triggerall = statetype = S
trigger1 = ctrl
trigger1 = stateno != [100, 109]

;===========================================================================
;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = var(59) = 0
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,499]

;---------------------------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 110
triggerall = var(59) = 0
trigger1 = (command = "DU") || (command = "DUF") || (command = "DUB") || (command = "abc")
trigger1 = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = command = "holdup"
trigger2 = stateno = 210
trigger2 = MoveHit >= 12

;---------------------------------------------------------------------------
;Guard Push (Stand)
[State -1, Guard Push (Stand)]
type = ChangeState
value = 160
trigger1 = command = "xyz"
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = stateno = 150
ignorehitpause = 1

;---------------------------------------------------------------------------
;Guard Push (Crouch)
[State -1, Guard Push (Crouch)]
type = ChangeState
value = 161
trigger1 = command = "xyz"
trigger1 = statetype = C
trigger1 = stateno = 152
ignorehitpause = 1

;---------------------------------------------------------------------------
;Guard Push (Air)
[State -1, Guard Push (Air)]
type = ChangeState
value = 162
trigger1 = command = "xyz"
trigger1 = statetype = A
trigger1 = stateno = 154
ignorehitpause = 1

;---------------------------------------------------------------------------
;Call Striker
[State -1, Call Striker]
type = ChangeState
value = 7376
triggerall = command = "yb"
triggerall = statetype != A
triggerall = numpartner != 0
triggerall = partner, stateno = 8982
triggerall = partner, movetype = I
triggerall = partner, var(17) != 0
triggerall = var(59) = 0
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Throw A
[State -1, Throw A]
type = ChangeState
value = 800
triggerall = (command = "y") || (command = "z")
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = (p2statetype = S) || (p2statetype = C)
triggerall = p2movetype != H
triggerall = var(59) = 0
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5

;---------------------------------------------------------------------------
;Air Throw
[State -1, Air Throw]
type = ChangeState
value = 830
triggerall = (command = "y") || (command = "z")
triggerall = statetype = A
triggerall = ctrl
triggerall = p2statetype = A
triggerall = p2movetype != H
triggerall = var(59) = 0
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5


;---------------------------------------------------------------------------
;Throw B
[State -1, Throw B]
type = ChangeState
value = 840
triggerall = (command = "b") || (command = "c")
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = (p2statetype = S) || (p2statetype = C)
triggerall = p2movetype != H
triggerall = var(59) = 0
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5

;===========================================================================
;---------------------------------------------------------------------------
;Launcher - Stand Medium Punch
[State -1, Launcher - Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "xa"
triggerall = var(59) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Stand High Punch
[State -1, Stand High Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Medium Kick
[State -1, Stand Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Stand Strong Kick
[State -1, Stand Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = var(59) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouch Light Punch
[State -1, Crouch Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouch Medium Punch
[State -1, Crouch Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouch Strong Punch
[State -1, Crouch Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouch Light Kick
[State -1, Crouch Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouch Medium Kick
[State -1, Crouch Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouch Strong Kick
[State -1, Crouch Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = var(59) = 0
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact
trigger3 = (stateno = 230) && MoveContact
trigger4 = (stateno = 400) && MoveContact
trigger5 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600) || (stateno = 630)

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600) || (stateno = 630)

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600)

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600) || (stateno = 630)

;---------------------------------------------------------------------------
;Jump Down Strong Kick
[State -1, Jump Down Strong Kick]
type = ChangeState
value = 655
triggerall = command = "down_c"
triggerall = var(59) = 0
trigger1 = Pos Y <= -60
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600) || (stateno = 630)

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
triggerall = var(59) = 0
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact
trigger2 = (stateno = 600) || (stateno = 630)

;---------------------------------------------------------------------------
;Roll (Short)
[State -1, Roll (Short)]
type = ChangeState
value = 1400
triggerall = (stateno = 5101) || (stateno = 5110)
trigger1 = command = "HCF_a"
trigger2 = command = "HCF_x"

;---------------------------------------------------------------------------
;Roll (Medium)
[State -1, Roll (Medium)]
type = ChangeState
value = 1410
triggerall = (stateno = 5101) || (stateno = 5110)
trigger1 = command = "HCF_b"
trigger2 = command = "HCF_y"

;---------------------------------------------------------------------------
;Roll (Long)
[State -1, Roll (Lonn)]
type = ChangeState
value = 1420
triggerall = (stateno = 5101) || (stateno = 5110)
trigger1 = command = "HCF_c"
trigger2 = command = "HCF_z"
